%define        libname  lib%{name}
%define        gitver %(echo %version | tr . _)
Name:          fuse
Version:       2.9.9
Release:       4mamba
Summary:       File System in Userspace (FUSE) utilities
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://github.com/libfuse/libfuse
Source:        https://github.com/libfuse/libfuse.git/fuse-%{version}/libfuse-%{version}.tar.bz2
Source1:       %{name}-initscript
Patch0:        %{name}-2.8.7-fix_linking_issues_with_gold_linker.patch
Patch1:        fuse-2.9.9-aarch64.patch
License:       GPL, LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
## AUTOBUILDREQ-END
BuildRequires: libselinux-devel
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description
With FUSE it is possible to implement a fully functional filesystem in a userspace program.
Features include:

- simple library API
- simple installation (no need to patch or recompile the kernel)
- secure implementation
- userspace - kernel interface is very efficient
- usable by non privileged users
- runs on Linux kernels 2.4.X and 2.6.X
- has proven very stable over time.

%package -n %{libname}
Summary:       File System in Userspace (FUSE) libraries
Group:         System/Libraries

%description -n %{libname}
Libraries for FUSE.

%package -n %{libname}-devel
Summary:       Devel package for %{libname}
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description -n %{libname}-devel
Libraries for FUSE.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q -n libfuse-%{version}
%define _default_patch_fuzz 1
%patch0 -p1
%ifarch aarch64
%patch1 -p1
%endif
sh ./makeconf.sh

%build
%configure \
  --sbindir=%{_prefix}

%make \
   MOUNT_FUSE_PATH=%{_sbindir}

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall \
   INIT_D_PATH=%{_initrddir} \
   MOUNT_FUSE_PATH=%{_sbindir}

# change permission to allow stripping
chmod 0755 %{buildroot}%{_bindir}/%{name}rmount

#install -D -m 755 %{S:1} \
#   %{buildroot}%{_initrddir}/%{name}
rm -f %{buildroot}%{_initrddir}/%{name}

## create compatibility symlinks
#install -d %{buildroot}%{_bindir}
#ln -s /bin/%{name}rmount %{buildroot}%{_bindir}/%{name}rmount
#ln -s /bin/ulockmgr_server %{buildroot}%{_bindir}/ulockmgr_server

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%config %{_sysconfdir}/udev/rules.d/99-%{name}.rules
%{_sbindir}/mount.fuse
%attr(4754,root,users) %{_bindir}/fusermount
%{_bindir}/ulockmgr_server
%{_bindir}/fusermount
%{_bindir}/ulockmgr_server
#%{_initrddir}/fuse
%{_mandir}/man1/fusermount.1*
%{_mandir}/man1/ulockmgr_server.1*
%{_mandir}/man8/mount.fuse.8*
%doc COPYING

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libfuse.so.*
%{_libdir}/libulockmgr.so.*
%doc AUTHORS COPYING.LIB

%files -n %{libname}-devel
%defattr(-,root,root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_includedir}/*.h
%{_libdir}/libfuse.a
%{_libdir}/libfuse.la
%{_libdir}/libfuse.so
%{_libdir}/libulockmgr.a
%{_libdir}/libulockmgr.la
%{_libdir}/libulockmgr.so
%{_libdir}/pkgconfig/*.pc
%doc ChangeLog NEWS README.NFS

%changelog
* Tue Apr 27 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.9-4mamba
- rebuilt in /usr instead of /

* Thu Dec 03 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.9-3mamba
- added patch for aarch64; remove initscript

* Tue Jul 23 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.9-2mamba
- restore the installation of custom initscript with chkconfig support

* Mon Jul 22 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.9-1mamba
- update to 2.9.9

* Mon Jul 22 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.7-2mamba
- fix initrd install path

* Sun Jul 31 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.7-1mamba
- update to 2.9.7

* Sat Jan 23 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.5-1mamba
- update to 2.9.5

* Sat May 23 2015 Automatic Build System <autodist@mambasoft.it> 2.9.4-1mamba
- automatic version update by autodist

* Sat Jul 06 2013 Automatic Build System <autodist@mambasoft.it> 2.9.3-1mamba
- automatic version update by autodist

* Sun Dec 02 2012 Automatic Build System <autodist@mambasoft.it> 2.9.2-1mamba
- automatic version update by autodist

* Sat Feb 25 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.7-1mamba
- update to 2.8.7
- added patch to fix linking issues with gold linker

* Thu Sep 30 2010 Automatic Build System <autodist@mambasoft.it> 2.8.5-1mamba
- automatic update by autodist

* Tue May 11 2010 Automatic Build System <autodist@mambasoft.it> 2.8.4-1mamba
- automatic update by autodist

* Thu Dec 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.1-1mamba
- update to 2.8.1
- fusermount: set suid for users group

* Thu Aug 27 2009 Automatic Build System <autodist@mambasoft.it> 2.8.0-1mamba
- automatic update by autodist

* Sun Nov 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7.4-1mamba
- automatic update by autodist

* Sat Nov 17 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.7.1-1mamba
- update to 2.7.1

* Sat Aug 25 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.7.0-1mamba
- update to 2.7.0

* Thu May 03 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.5-1mamba
- update to 2.6.5

* Fri Apr 27 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.3-2mamba
- allow users to umount fuse filesystems

* Wed Apr 18 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.3-1mamba
- update to version 2.6.3 by autospec
- added init script

* Mon Oct 16 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.3-2qilnx
- patched configuration file for udev to make it compatibile with latest udev
  versions
- replace the udev configuration rule and do a backup copy of the previous one

* Tue Jun 27 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.3-1qilnx
- update to version 2.5.3 by autospec

* Fri Apr 14 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.2-2qilnx
- added autoboot for fuse module

* Mon Mar 13 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.2-1qilnx
- package created by autospec
